/**
 * Creates a new Promise that wraps a provided Promise with a timeout.
 * If the original Promise resolves/rejects before the timeout
 * expires, the new Promise will resolve/reject as usual,
 * otherwise, it will reject with a timeout message.
 *
 * @param originalPromise the original Promise to wrap with the timeout
 * @param ms milliseconds to wait before rejecting due to timeout
 * @param timeoutMessage optional custom timeout message
 */
export function timeout(originalPromise, ms, timeoutMessage) {
    if (timeoutMessage === void 0) { timeoutMessage = "timed out after " + ms + "ms"; }
    return new Promise(function (resolve, reject) {
        var timerId = setTimeout(function () { return reject(new Error(timeoutMessage)); }, ms);
        originalPromise.then(function (resolvedValue) {
            clearTimeout(timerId);
            resolve(resolvedValue);
        }, function (rejectReason) {
            clearTimeout(timerId);
            reject(rejectReason);
        });
    });
}
//# sourceMappingURL=timeout.js.map